@@ -14,15 +14,15 @@ use 5.005;
 use strict;
 
 BEGIN {
-    $Module::Package::VERSION = '0.21';
+    $Module::Package::VERSION = '0.22';
     $inc::Module::Package::VERSION ||= $Module::Package::VERSION;
     @inc::Module::Package::ISA = __PACKAGE__;
 }
 
 sub import {
     my $class = shift;
-    # Placate a check in Module::Install
     $INC{'inc/Module/Install.pm'} = __FILE__;
+    unshift @INC, 'inc' unless $INC[0] eq 'inc';
     eval "use Module::Install 1.01 (); 1" or $class->error($@);
 
     package main;
@@ -37,6 +37,7 @@ sub import {
     }
 }
 
+# XXX Remove this when things are stable.
 sub error {
     my ($class, $error) = @_;
     if (-e 'inc' and not -e 'inc/.author') {
